// Copyright (C) 2022 The OKit Authors
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
// OR OTHER DEALINGS IN THE SOFTWARE.

package http

import (
	"net/http"
	"strings"
	"time"
)

func NewEndpoint() *Endpoint {
	return &Endpoint{}
}

type Endpoint struct{}

func (e *Endpoint) Health(w http.ResponseWriter, r *http.Request) {
	http.ServeContent(w, r, "", time.Now(), strings.NewReader(`{"status":"ok"}`))
}

func (e *Endpoint) Metrics(w http.ResponseWriter, r *http.Request) {
	// Render metrics endpoint
	// Unlike prometheus, metrics are pushed and not scraped. So there's no need for a complicated protocol here.
}

func (e *Endpoint) Trace(w http.ResponseWriter, r *http.Request) {
	// Lookup Trace by TraceID
	// Render a flamegraph for a given trace ID
}
